@@ -1,3 +1,3 @@
 #!/usr/bin/env python
 exec(open('report.py', 'r').read())
-fig.savefig('result.pdf')
\ No newline at end of file
+fig.savefig('result.png')
