@@ -2,11 +2,13 @@ extern crate rustc_serialize;
 extern crate rmp_serialize;
 // extern crate cpython;
 
-// re-exports
 mod axes2d;
-pub mod backend;
 mod figure;
+mod scatter;
 
-pub use axes2d::{Axes2D, Scatter};
+// re-exports
+pub mod backend;
+pub use axes2d::{Axes2D, PlotData};
 pub use backend::Backend;
 pub use figure::Figure;
+pub use scatter::Scatter;
